@@ -7,7 +7,7 @@ use base ('Exporter');
 
 use vars qw{$VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS};
 
-$VERSION = '0.421';
+$VERSION = '0.422';
 
 @EXPORT = ();
 @EXPORT_OK = qw(any all none notall one
@@ -20,7 +20,7 @@ $VERSION = '0.421';
           firstidx lastidx onlyidx
           firstval lastval onlyval
           firstres lastres onlyres
-          singleton duplicates frequency occurances mode
+          singleton duplicates frequency occurrences mode
           each_array each_arrayref
           pairwise natatime
           arrayify mesh zip6 uniq listcmp
@@ -66,9 +66,16 @@ List::MoreUtils::XS - Provide compiled List::MoreUtils functions
   my $i = firstidx { $_ eq 'yeah' } @foo;
   # on sorted - always first, but might not be 'yeah'
   my $j = lower_bound { $_ cmp 'yeah' } @bar;
-  # on sorted - any of occurances, is surely 'yeah'
+  # on sorted - any of occurrences, is surely 'yeah'
   my $k = bsearchidx { $_ cmp 'yeah' } @bar;
 
+=head1 DESCRIPTION
+
+List::MoreUtils::XS is a backend for List::MoreUtils. Even if it's possible
+(because of user wishes) to have it practically independent from
+L<List::MoreUtils>, it technically depend on C<List::MoreUtils>. Since it's
+only a backend, the API is not public and can change without any warning.
+
 =head1 SEE ALSO
 
 L<List::Util>, L<List::AllUtils>
