@@ -2,13 +2,6 @@
 use Test::More;
 use Test::LMU;
 
-SCOPE:
-{
-    my @list = ();
-    is(0, (binsert { $_ cmp "Hello" } "Hello", @list), "Inserting into empty list");
-    is(1, (binsert { $_ cmp "world" } "world", @list), "Inserting into one-item list");
-}
-
 my @even = map { $_ * 2 } 1 .. 100;
 my @odd  = map { $_ * 2 - 1 } 1 .. 100;
 my (@expected, @in);
@@ -43,7 +36,7 @@ foreach my $v (reverse @even)
 }
 is_deeply(\@in, \@expected, "binsert even elements reversely into odd list succeeded");
 
-@in       = @even;
+@in = @even;
 @expected = map { $_, $_ } @in;
 foreach my $v (@even)
 {
@@ -51,7 +44,7 @@ foreach my $v (@even)
 }
 is_deeply(\@in, \@expected, "binsert existing even elements into even list succeeded");
 
-@in       = @even;
+@in = @even;
 @expected = map { $_, $_ } @in;
 foreach my $v (reverse @even)
 {
